@@ -38,5 +38,5 @@ __path__ = __import__('pkgutil').extend_path(__path__, __name__)  # type: ignore
 
 __all__ = ('get_lock', 'release_lock', 'Translation', 'NullTranslation', 'Locale', 'I18N_Error')
 
+from univention.lib.i18n import I18N_Error, Locale, NullTranslation, Translation
 from univention.lib.locking import get_lock, release_lock
-from univention.lib.i18n import Translation, NullTranslation, Locale, I18N_Error
